@@ -1,7 +1,7 @@
 /*
  *  birthdaydlg.cpp  -  dialog to pick birthdays from address book
  *  Program:  kalarm
- *  Copyright © 2002-2012,2018 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 
 #include "birthdaydlg.h"
 
-#include "alarmcalendar.h"
 #include "birthdaymodel.h"
 #include "editdlgtypes.h"
 #include "fontcolourbutton.h"
@@ -29,6 +28,7 @@
 #include "preferences.h"
 #include "reminder.h"
 #include "repetitionbutton.h"
+#include "resourcescalendar.h"
 #include "soundpicker.h"
 #include "specialactions.h"
 #include "lib/checkbox.h"
@@ -40,7 +40,6 @@
 
 #include <KLocalizedString>
 #include <KConfigGroup>
-#include <KMessageBox>
 #include <KStandardAction>
 #include <KActionCollection>
 #include <KDescendantsProxyModel>
@@ -65,7 +64,6 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     setWindowTitle(i18nc("@title:window", "Import Birthdays From KAddressBook"));
 
     QVBoxLayout* topLayout = new QVBoxLayout(this);
-    topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     // Prefix and suffix to the name in the alarm text
     // Get default prefix and suffix texts from config file
@@ -76,9 +74,6 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     QGroupBox* textGroup = new QGroupBox(i18nc("@title:group", "Alarm Text"), this);
     topLayout->addWidget(textGroup);
     QGridLayout* grid = new QGridLayout(textGroup);
-    int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    grid->setContentsMargins(dcm, dcm, dcm, dcm);
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     QLabel* label = new QLabel(i18nc("@label:textbox", "Prefix:"), textGroup);
     label->setFixedSize(label->sizeHint());
     grid->addWidget(label, 0, 0);
@@ -149,8 +144,6 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     group = new QGroupBox(i18nc("@title:group", "Alarm Configuration"), this);
     topLayout->addWidget(group);
     QVBoxLayout* groupLayout = new QVBoxLayout(group);
-    groupLayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    groupLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     // Sound checkbox and file selector
     QHBoxLayout* hlayout = new QHBoxLayout();
@@ -159,7 +152,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     mSoundPicker = new SoundPicker(group);
     mSoundPicker->setFixedSize(mSoundPicker->sizeHint());
     hlayout->addWidget(mSoundPicker);
-    hlayout->addSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    hlayout->addSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     hlayout->addStretch();
 
     // Font and colour choice button and sample text
@@ -182,12 +175,12 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     // Acknowledgement confirmation required - default = no confirmation
     hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
-    hlayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    hlayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     groupLayout->addLayout(hlayout);
     mConfirmAck = EditDisplayAlarmDlg::createConfirmAckCheckbox(group);
     mConfirmAck->setFixedSize(mConfirmAck->sizeHint());
     hlayout->addWidget(mConfirmAck);
-    hlayout->addSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    hlayout->addSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     hlayout->addStretch();
 
     if (ShellProcess::authorised())    // don't display if shell commands not allowed (e.g. kiosk mode)
@@ -201,7 +194,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     // Late display checkbox - default = allow late display
     hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
-    hlayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    hlayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     groupLayout->addLayout(hlayout);
     mLateCancel = new LateCancelSelector(false, group);
     mLateCancel->setFixedSize(mLateCancel->sizeHint());
