@@ -1,7 +1,7 @@
 /*
  *  deferdlg.cpp  -  dialog to defer an alarm
  *  Program:  kalarm
- *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,11 @@
 
 #include "deferdlg.h"
 
-#include "alarmcalendar.h"
 #include "alarmtimewidget.h"
 #include "functions.h"
 #include "kalarmapp.h"
+#include "resourcescalendar.h"
+#include "resources/resources.h"
 #include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
@@ -50,14 +51,13 @@ DeferAlarmDlg::DeferAlarmDlg(const DateTime& initialDT, bool anyTimeOption, bool
     setWindowTitle(i18nc("@title:window", "Defer Alarm"));
 
     QVBoxLayout* layout = new QVBoxLayout(this);
-    layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     mTimeWidget = new AlarmTimeWidget((anyTimeOption ? AlarmTimeWidget::DEFER_ANY_TIME : AlarmTimeWidget::DEFER_TIME), this);
     mTimeWidget->setDateTime(initialDT);
     mTimeWidget->setMinDateTimeIsCurrent();
     connect(mTimeWidget, &AlarmTimeWidget::pastMax, this, &DeferAlarmDlg::slotPastLimit);
     layout->addWidget(mTimeWidget);
-    layout->addSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    layout->addSpacing(style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     mButtonBox = new QDialogButtonBox(this);
     layout->addWidget(mButtonBox);
@@ -94,9 +94,10 @@ void DeferAlarmDlg::slotOk()
     if (!mLimitEventId.isEmpty())
     {
         // Get the event being deferred
-        const KAEvent* event = AlarmCalendar::getEvent(mLimitEventId);
-        if (event)
-            endTime = event->deferralLimit(&limitType);
+        Resource resource = Resources::resource(mLimitEventId.resourceId());
+        const KAEvent event = resource.event(mLimitEventId.eventId());
+        if (event.isValid())
+            endTime = event.deferralLimit(&limitType);
     }
     else
     {
@@ -166,10 +167,11 @@ void DeferAlarmDlg::setLimit(const DateTime& limit)
 */
 DateTime DeferAlarmDlg::setLimit(const KAEvent& event)
 {
-    Q_ASSERT(event.collectionId() >= 0);
+    Q_ASSERT(event.resourceId() >= 0);
     mLimitEventId = EventId(event);
-    const KAEvent* evnt = AlarmCalendar::getEvent(mLimitEventId);
-    mLimitDateTime = evnt ? evnt->deferralLimit() : DateTime();
+    Resource resource = Resources::resource(event.resourceId());
+    const KAEvent evnt = resource.event(event.id());
+    mLimitDateTime = evnt.isValid() ? evnt.deferralLimit() : DateTime();
     mTimeWidget->setMaxDateTime(mLimitDateTime);
     return mLimitDateTime;
 }
