@@ -1,7 +1,7 @@
 /*
  *  editdlgtypes.h  -  dialogues to create or edit alarm or alarm template types
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -175,6 +175,7 @@ class EditCommandAlarmDlg : public EditAlarmDlg
     private:
         // Command alarm options
         CommandEdit*      mCmdEdit;
+        CheckBox*         mCmdDontShowError;
         QGroupBox*        mCmdOutputBox;
         ButtonGroup*      mCmdOutputGroup;     // what to do with command output
         RadioButton*      mCmdExecInTerm;
@@ -185,6 +186,7 @@ class EditCommandAlarmDlg : public EditAlarmDlg
 
         // Initial state of all controls
         bool              mSavedCmdScript;        // mCmdEdit->isScript() status
+        bool              mSavedCmdDontShowError; // mCmdDontShowError value
         QAbstractButton*  mSavedCmdOutputRadio;   // selected button in mCmdOutputGroup
         QString           mSavedCmdLogFile;       // mCmdLogFileEdit value
 };
