@@ -1,7 +1,7 @@
 /*
  *  fontcolour.cpp  -  font and colour chooser widget
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,11 +28,9 @@
 #include <KFontChooser>
 
 #include <QGroupBox>
-#include <QPushButton>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <QStyle>
 
 
 FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontList,
@@ -40,17 +38,15 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
     : QWidget(parent)
 {
     QVBoxLayout* topLayout = new QVBoxLayout(this);
-    topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     QWidget* page = this;
     if (!frameLabel.isNull())
     {
         page = new QGroupBox(frameLabel, this);
         topLayout->addWidget(page);
         topLayout = new QVBoxLayout(page);
-        int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-        topLayout->setContentsMargins(dcm, dcm, dcm, dcm);
-        topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     }
+    else
+        topLayout->setContentsMargins(0, 0, 0, 0);
     QHBoxLayout* hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(hlayout);
@@ -63,7 +59,6 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
         colourLayout->addWidget(box);
         QHBoxLayout* boxHLayout = new QHBoxLayout(box);
         boxHLayout->setContentsMargins(0, 0, 0, 0);
-        boxHLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing) / 2);
 
         QLabel* label = new QLabel(i18nc("@label:listbox", "Foreground color:"), box);
         boxHLayout->addWidget(label);
@@ -79,7 +74,6 @@ FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontLis
     colourLayout->addWidget(box);
     QHBoxLayout* boxHLayout = new QHBoxLayout(box);
     boxHLayout->setContentsMargins(0, 0, 0, 0);
-    boxHLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing) / 2);
 
     QLabel* label = new QLabel(i18nc("@label:listbox", "Background color:"), box);
     boxHLayout->addWidget(label);
