@@ -21,7 +21,7 @@
 #ifndef COLOURBUTTON_H
 #define COLOURBUTTON_H
 
-#include <kcolorbutton.h>
+#include <KColorButton>
 
 
 /**
@@ -59,7 +59,7 @@ class ColourButton : public KColorButton
         void         keyPressEvent(QKeyEvent*) override;
         void         keyReleaseEvent(QKeyEvent*) override;
     private:
-        bool         mReadOnly{false};        // value cannot be changed
+        bool         mReadOnly {false};        // value cannot be changed
 };
 
 #endif // COLOURBUTTON_H
