@@ -21,7 +21,7 @@
 #ifndef COMBOBOX_H
 #define COMBOBOX_H
 
-#include <kcombobox.h>
+#include <KComboBox>
 class QMouseEvent;
 class QKeyEvent;
 
@@ -58,7 +58,7 @@ class ComboBox : public KComboBox
         void         keyPressEvent(QKeyEvent*) override;
         void         keyReleaseEvent(QKeyEvent*) override;
     private:
-        bool    mReadOnly{false};      // value cannot be changed
+        bool    mReadOnly {false};      // value cannot be changed
 };
 
 #endif // COMBOBOX_H
