@@ -1,7 +1,7 @@
 /*
  *  desktop.cpp  -  desktop functions
  *  Program:  kalarm
- *  Copyright © 2008-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2008-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,6 +32,8 @@
 namespace Desktop
 {
 
+QWidget* (*mMainWindowFunc)() {nullptr};
+
 /******************************************************************************
 * Find the identity of the desktop we are running on.
 */
@@ -67,6 +69,19 @@ QRect workArea(int screen)
     return screens[screen]->availableGeometry();
 }
 
+/******************************************************************************
+* Return the top level application window, for use as parent for dialogues etc.
+*/
+QWidget* mainWindow()
+{
+    return (*mMainWindowFunc)();
+}
+
+void setMainWindowFunc(QWidget* (*func)())
+{
+    mMainWindowFunc = func;
+}
+
 } // namespace Desktop
 
 // vim: et sw=4:
