@@ -1,7 +1,7 @@
 /*
  *  synchtimer.h  -  timers which synchronize to time boundaries
  *  Program:  kalarm
- *  Copyright © 2004,2005 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004-2020 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ class SynchTimer : public QObject
         SynchTimer();
         virtual void        start() = 0;
         void                connecT(QObject* receiver, const char* member);
-        void                disconnecT(QObject* receiver, const char* member = nullptr);
+        virtual void        disconnecT(QObject* receiver, const char* member = nullptr);
         bool                hasConnections() const   { return !mConnections.isEmpty(); }
 
         QTimer*             mTimer;
@@ -134,6 +134,16 @@ class DailyTimer : public SynchTimer
          *                @p receiver will be disconnected.
          */
         static void disconnect(const QTime& timeOfDay, QObject* receiver, const char* member = nullptr);
+    protected:
+        /** Construct an instance.
+         *  The constructor is protected to ensure that for variable timers, only derived classes
+         *  can construct instances. This ensures that multiple timers are not created for the same
+         *  use.
+         */
+        DailyTimer(const QTime&, bool fixed);
+
+        void disconnecT(QObject* receiver, const char* member = nullptr) override;
+
         /** Change the time at which this variable timer triggers.
          *  @param newTimeOfDay New time at which the timer should trigger.
          *  @param triggerMissed If true, and if @p newTimeOfDay < @p oldTimeOfDay, and if the current
@@ -144,13 +154,6 @@ class DailyTimer : public SynchTimer
         /** Return the current time of day at which this variable timer triggers. */
         QTime timeOfDay() const  { return mTime; }
 
-    protected:
-        /** Construct an instance.
-         *  The constructor is protected to ensure that for variable timers, only derived classes
-         *  can construct instances. This ensures that multiple timers are not created for the same
-         *  use.
-         */
-        DailyTimer(const QTime&, bool fixed);
         /** Return the instance which triggers at the specified fixed time of day,
          *  optionally creating a new instance if necessary.
          *  @param timeOfDay Time at which the timer triggers.
