@@ -27,6 +27,7 @@
 #include "mainwindowbase.h"
 #include "resources/resource.h"
 #include "lib/autoqpointer.h"
+#include "lib/shellprocess.h"
 
 #include <KAlarmCal/KAEvent>
 
@@ -46,7 +47,6 @@ class QLabel;
 class QTemporaryFile;
 class DeferAlarmDlg;
 class EditAlarmDlg;
-class ShellProcess;
 class AudioThread;
 
 using namespace KAlarmCal;
@@ -59,10 +59,11 @@ class MessageWin : public MainWindowBase
         Q_OBJECT
     public:
         enum {                // flags for constructor
-            NO_RESCHEDULE = 0x01,    // don't reschedule the event once it has displayed
-            NO_DEFER      = 0x02,    // don't display the Defer button
-            ALWAYS_HIDE   = 0x04,    // never show the window (e.g. for audio-only alarms)
-            NO_INIT_VIEW  = 0x08     // for internal MessageWin use only
+            NO_RESCHEDULE    = 0x01,    // don't reschedule the event once it has displayed
+            NO_DEFER         = 0x02,    // don't display the Defer button
+            NoRecordCmdError = 0x04,    // don't record error executing command
+            ALWAYS_HIDE      = 0x08,    // never show the window (e.g. for audio-only alarms)
+            NO_INIT_VIEW     = 0x10     // for internal MessageWin use only
         };
 
         MessageWin();     // for session management restoration only
@@ -118,6 +119,7 @@ class MessageWin : public MainWindowBase
         void                setRemainingTextMinute();
         void                frameDrawn();
         void                readProcessOutput(ShellProcess*);
+        void                commandCompleted(ShellProcess::Status);
 
     private:
         MessageWin(const KAEvent*, const DateTime& alarmDateTime, const QStringList& errmsgs,
@@ -193,6 +195,7 @@ class MessageWin : public MainWindowBase
         bool                mRecreating {false};      // window is about to be deleted and immediately recreated
         bool                mBeep;
         bool                mSpeak;                   // the message should be spoken via kttsd
+        bool                mNoRecordCmdError {false}; // don't record command alarm errors
         bool                mRescheduleEvent {false}; // true to delete event after message has been displayed
         bool                mShown {false};           // true once the window has been displayed
         bool                mPositioning {false};     // true when the window is being positioned initially
