@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #include "prefdlg.h"
 #include "prefdlg_p.h"
 
-#include "alarmcalendar.h"
 #include "alarmtimewidget.h"
 #include "editdlg.h"
 #include "editdlgtypes.h"
@@ -33,12 +32,14 @@
 #include "mainwindow.h"
 #include "preferences.h"
 #include "recurrenceedit.h"
+#include "resourcescalendar.h"
 #include "sounddlg.h"
 #include "soundpicker.h"
 #include "specialactions.h"
 #include "traywindow.h"
 #include "resources/resources.h"
 #include "lib/buttongroup.h"
+#include "lib/checkbox.h"
 #include "lib/colourbutton.h"
 #include "lib/config.h"
 #include "lib/desktop.h"
@@ -116,7 +117,8 @@ static QString xtermCommands[] = {
 = Class KAlarmPrefDlg
 =============================================================================*/
 
-KAlarmPrefDlg* KAlarmPrefDlg::mInstance = nullptr;
+KAlarmPrefDlg*         KAlarmPrefDlg::mInstance = nullptr;
+KAlarmPrefDlg::TabType KAlarmPrefDlg::mLastTab  = AnyTab;
 
 void KAlarmPrefDlg::display()
 {
@@ -126,10 +128,12 @@ void KAlarmPrefDlg::display()
         QSize s;
         if (Config::readWindowSize(PREF_DIALOG_NAME, s))
             mInstance->resize(s);
+        mInstance->restoreTab();
         mInstance->show();
     }
     else
     {
+        mInstance->restoreTab();
 #if KDEPIM_HAVE_X11
         KWindowInfo info = KWindowInfo(mInstance->winId(), NET::WMGeometry | NET::WMDesktop);
         KWindowSystem::setCurrentDesktop(info.desktop());
@@ -191,6 +195,7 @@ KAlarmPrefDlg::KAlarmPrefDlg()
     connect(button(QDialogButtonBox::Apply), &QAbstractButton::clicked, this, &KAlarmPrefDlg::slotApply);
     connect(button(QDialogButtonBox::RestoreDefaults), &QAbstractButton::clicked, this, &KAlarmPrefDlg::slotDefault);
     connect(button(QDialogButtonBox::Help), &QAbstractButton::clicked, this, &KAlarmPrefDlg::slotHelp);
+    connect(this, &KPageDialog::currentPageChanged, this, &KAlarmPrefDlg::slotTabChanged);
     restore(false);
     adjustSize();
 }
@@ -337,11 +342,45 @@ void KAlarmPrefDlg::resizeEvent(QResizeEvent* re)
     KPageDialog::resizeEvent(re);
 }
 
+/******************************************************************************
+* Called when a new tab is selected, to note which one it is.
+*/
+void KAlarmPrefDlg::slotTabChanged(KPageWidgetItem* item)
+{
+    mLastTab = (item == mMiscPageItem)  ? Misc
+             : (item == mTimePageItem)  ? Time
+             : (item == mStorePageItem) ? Store
+             : (item == mEditPageItem)  ? Edit
+             : (item == mEmailPageItem) ? Email
+             : (item == mViewPageItem)  ? View : AnyTab;
+}
+
+/******************************************************************************
+* Selects the tab noted in mLastTab.
+*/
+void KAlarmPrefDlg::restoreTab()
+{
+    KPageWidgetItem* item = nullptr;
+    switch (mLastTab)
+    {
+        case Misc:   item = mMiscPageItem;   break;
+        case Time:   item = mTimePageItem;   break;
+        case Store:  item = mStorePageItem;  break;
+        case Edit:   item = mEditPageItem;   break;
+        case Email:  item = mEmailPageItem;  break;
+        case View:   item = mViewPageItem;   break;
+        default:
+            return;
+    }
+    setCurrentPage(item);
+}
+
 
 /*=============================================================================
 = Class PrefsTabBase
 =============================================================================*/
 int PrefsTabBase::mIndentWidth = 0;
+int PrefsTabBase::mGridIndentWidth = 0;
 
 PrefsTabBase::PrefsTabBase(StackedScrollGroup* scrollGroup)
     : StackedScrollWidget(scrollGroup)
@@ -350,13 +389,11 @@ PrefsTabBase::PrefsTabBase(StackedScrollGroup* scrollGroup)
     setWidget(topWidget);
     mTopLayout = new QVBoxLayout(topWidget);
     mTopLayout->setContentsMargins(0, 0, 0, 0);
-    mTopLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     if (!mIndentWidth)
     {
-        QRadioButton radio(this);
-        QStyleOptionButton opt;
-        opt.initFrom(&radio);
-        mIndentWidth = style()->subElementRect(QStyle::SE_RadioButtonIndicator, &opt).width();
+        QCheckBox cb(this);
+        mIndentWidth = CheckBox::textIndent(&cb);
+        mGridIndentWidth = mIndentWidth - style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing);
     }
 }
 
@@ -407,9 +444,6 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Run Mode"));
     topLayout()->addWidget(group);
     QVBoxLayout* vlayout = new QVBoxLayout(group);
-    const int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    vlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     // Start at login
     mAutoStart = new QCheckBox(i18nc("@option:check", "Start at login"), group);
@@ -427,7 +461,6 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     QWidget* widget = new QWidget;  // this is for consistent left alignment
     topLayout()->addWidget(widget);
     QHBoxLayout* hbox = new QHBoxLayout(widget);
-    hbox->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mConfirmAlarmDeletion = new QCheckBox(i18nc("@option:check", "Confirm alarm deletions"));
     mConfirmAlarmDeletion->setMinimumSize(mConfirmAlarmDeletion->sizeHint());
     mConfirmAlarmDeletion->setWhatsThis(i18nc("@info:whatsthis", "Check to be prompted for confirmation each time you delete an alarm."));
@@ -438,7 +471,6 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     topLayout()->addWidget(widget);
     hbox = new QHBoxLayout(widget);
-    hbox->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     QLabel* label = new QLabel(i18nc("@label:spinbox", "Default defer time interval:"));
     hbox->addWidget(label);
     mDefaultDeferTime = new TimeSpinBox(1, 5999);
@@ -454,8 +486,6 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     group->setWhatsThis(i18nc("@info:whatsthis", "Choose which application to use when a command alarm is executed in a terminal window"));
     topLayout()->addWidget(group);
     QGridLayout* grid = new QGridLayout(group);
-    grid->setContentsMargins(dcm, dcm, dcm, dcm);
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     int row = 0;
 
     mXtermType = new ButtonGroup(group);
@@ -485,7 +515,6 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
 
     // QHBox used here doesn't allow the QLineEdit to expand!?
     QHBoxLayout* hlayout = new QHBoxLayout();
-    hlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     grid->addLayout(hlayout, row + 1, 0, 1, 3, Qt::AlignLeft);
     QRadioButton* radio = new QRadioButton(i18nc("@option:radio Other terminal window command", "Other:"), group);
     hlayout->addWidget(radio);
@@ -614,7 +643,6 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     itemBox->addWidget(widget);
     QHBoxLayout* box =  new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     QLabel* label = new QLabel(i18nc("@label:listbox", "Time zone:"));
     box->addWidget(label);
     addAlignedLabel(label);
@@ -636,7 +664,6 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     itemBox->addWidget(widget);
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     label = new QLabel(i18nc("@label:listbox", "Holiday region:"));
     addAlignedLabel(label);
     box->addWidget(label);
@@ -674,7 +701,6 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     itemBox->addWidget(widget);
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     label = new QLabel(i18nc("@label:spinbox", "Start of day for date-only alarms:"));
     addAlignedLabel(label);
     box->addWidget(label);
@@ -690,14 +716,10 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Working Hours"));
     topLayout()->addWidget(group);
     QBoxLayout* layout = new QVBoxLayout(group);
-    const int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    layout->setContentsMargins(dcm, dcm, dcm, dcm);
-    layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     QWidget* daybox = new QWidget(group);   // this is to control the QWhatsThis text display area
     layout->addWidget(daybox);
     QGridLayout* wgrid = new QGridLayout(daybox);
-    wgrid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     const QLocale locale;
     for (int i = 0;  i < 7;  ++i)
     {
@@ -715,7 +737,6 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     itemBox->addWidget(widget);
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     label = new QLabel(i18nc("@label:spinbox", "Daily start time:"));
     addAlignedLabel(label);
     box->addWidget(label);
@@ -735,7 +756,6 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     itemBox->addWidget(widget);
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     label = new QLabel(i18nc("@label:spinbox", "Daily end time:"));
     addAlignedLabel(label);
     box->addWidget(label);
@@ -751,14 +771,11 @@ TimePrefTab::TimePrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "KOrganizer"));
     topLayout()->addWidget(group);
     layout = new QVBoxLayout(group);
-    layout->setContentsMargins(dcm, dcm, dcm, dcm);
-    layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     layout->addWidget(widget);
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     label = new QLabel(i18nc("@label:spinbox", "KOrganizer event duration:"));
     addAlignedLabel(label);
     box->addWidget(label);
@@ -831,9 +848,6 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     topLayout()->addWidget(group);
     QButtonGroup* bgroup = new QButtonGroup(group);
     QBoxLayout* layout = new QVBoxLayout(group);
-    const int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    layout->setContentsMargins(dcm, dcm, dcm, dcm);
-    layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     mDefaultResource = new QRadioButton(i18nc("@option:radio", "Store in default calendar"), group);
     bgroup->addButton(mDefaultResource);
@@ -850,10 +864,8 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "Archived Alarms"));
     topLayout()->addWidget(group);
     QGridLayout* grid = new QGridLayout(group);
-    grid->setContentsMargins(dcm, dcm, dcm, dcm);
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     grid->setColumnStretch(1, 1);
-    grid->setColumnMinimumWidth(0, indentWidth());
+    grid->setColumnMinimumWidth(0, gridIndentWidth());
     mKeepArchived = new QCheckBox(i18nc("@option:check", "Keep alarms after expiry"), group);
     connect(mKeepArchived, &QAbstractButton::toggled, this, &StorePrefTab::slotArchivedToggled);
     mKeepArchived->setWhatsThis(
@@ -863,7 +875,6 @@ StorePrefTab::StorePrefTab(StackedScrollGroup* scrollGroup)
     QWidget* widget = new QWidget;
     QHBoxLayout* box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mPurgeArchived = new QCheckBox(i18nc("@option:check", "Discard archived alarms after:"));
     mPurgeArchived->setMinimumSize(mPurgeArchived->sizeHint());
     box->addWidget(mPurgeArchived);
@@ -965,7 +976,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     QWidget* widget = new QWidget;
     topLayout()->addWidget(widget);
     QHBoxLayout* box = new QHBoxLayout(widget);
-    box->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    box->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     QLabel* label = new QLabel(i18nc("@label", "Email client:"));
     box->addWidget(label);
     mEmailClient = new ButtonGroup(widget);
@@ -1009,9 +1020,6 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Your Email Address"));
     topLayout()->addWidget(group);
     QGridLayout* grid = new QGridLayout(group);
-    const int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    grid->setContentsMargins(dcm, dcm, dcm, dcm);
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     grid->setColumnStretch(2, 1);
 
     // 'From' email address controls ...
@@ -1050,7 +1058,7 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     grid->addWidget(mFromKMailButton, 3, 1, 1, 2, Qt::AlignLeft);
 
     // 'Bcc' email address controls ...
-    grid->setRowMinimumHeight(4, style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    grid->setRowMinimumHeight(4, style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     label = new Label(i18nc("@label 'Bcc' email address", "Bcc:"), group);
     grid->addWidget(label, 5, 0);
     mBccAddressGroup = new ButtonGroup(group);
@@ -1231,7 +1239,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     tgLayout->addWidget(widget);
     box = new QHBoxLayout(widget);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     box->setContentsMargins(0, 0, 0, 0);
     QLabel* label = new QLabel(i18nc("@label:listbox", "Recurrence:"));
     box->addWidget(label);
@@ -1253,7 +1260,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     tgLayout->addWidget(febBox);
     QVBoxLayout* vbox = new QVBoxLayout(febBox);
     vbox->setContentsMargins(0, 0, 0, 0);
-    vbox->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     label = new QLabel(i18nc("@label", "In non-leap years, repeat yearly February 29th alarms on:"));
     label->setAlignment(Qt::AlignLeft);
     label->setWordWrap(true);
@@ -1261,10 +1267,10 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     box = new QHBoxLayout();
     vbox->addLayout(box);
     vbox->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    box->setSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     mFeb29 = new ButtonGroup(febBox);
     widget = new QWidget();
-    widget->setFixedWidth(3 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    widget->setFixedWidth(3 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     box->addWidget(widget);
     QRadioButton* radio = new QRadioButton(i18nc("@option:radio", "February 2&8th"));
     radio->setMinimumSize(radio->sizeHint());
@@ -1288,9 +1294,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Display Alarms"));
     ttLayout->addWidget(group);
     QVBoxLayout* vlayout = new QVBoxLayout(group);
-    const int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    vlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     mConfirmAck = new QCheckBox(EditDisplayAlarmDlg::i18n_chk_ConfirmAck());
     mConfirmAck->setMinimumSize(mConfirmAck->sizeHint());
@@ -1306,7 +1309,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     vlayout->addWidget(widget);
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     label = new QLabel(i18nc("@label:listbox", "Reminder units:"));
     box->addWidget(label);
     mReminderUnits = new QComboBox();
@@ -1323,8 +1325,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     QGroupBox* bbox = new QGroupBox(i18nc("@title:group Audio options group", "Sound"));
     ttLayout->addWidget(bbox);
     vlayout = new QVBoxLayout(bbox);
-    vlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     QHBoxLayout* hlayout = new QHBoxLayout;
     hlayout->setContentsMargins(0, 0, 0, 0);
@@ -1348,7 +1348,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mSoundFileLabel = new QLabel(i18nc("@label:textbox", "Sound file:"));
     box->addWidget(mSoundFileLabel);
     mSoundFile = new QLineEdit();
@@ -1366,8 +1365,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "Command Alarms"));
     ttLayout->addWidget(group);
     vlayout = new QVBoxLayout(group);
-    vlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
     vlayout->addLayout(hlayout);
@@ -1387,8 +1384,6 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "Email Alarms"));
     ttLayout->addWidget(group);
     vlayout = new QVBoxLayout(group);
-    vlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     // BCC email to sender
     mEmailBcc = new QCheckBox(EditEmailAlarmDlg::i18n_chk_CopyEmailToSelf(), group);
@@ -1401,6 +1396,7 @@ EditPrefTab::EditPrefTab(StackedScrollGroup* scrollGroup)
     // FONT / COLOUR TAB
     mFontChooser = new FontColourChooser(topFontColour, QStringList(), i18nc("@title:group", "Message Font && Color"), true);
     tfLayout->addWidget(mFontChooser);
+    tfLayout->setContentsMargins(0, 0, 0, 0);
 }
 
 void EditPrefTab::restore(bool, bool allTabs)
@@ -1602,16 +1598,10 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
 
     QWidget* widget = new QWidget;
     QVBoxLayout* topGeneral = new QVBoxLayout(widget);
-    const int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    const int m = dcm / 2;
-    topGeneral->setContentsMargins(m, m, m, m);
-    topGeneral->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTabGeneral = mTabs->addTab(widget, i18nc("@title:tab", "General"));
 
     widget =  new QWidget;
     QVBoxLayout* topWindows = new QVBoxLayout(widget);
-    topWindows->setContentsMargins(m, m, m, m);
-    topWindows->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTabWindows = mTabs->addTab(widget, i18nc("@title:tab", "Alarm Windows"));
 
     // Run-in-system-tray check box or group.
@@ -1640,10 +1630,8 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
         mShowInSystemTrayGroup->setWhatsThis(showInSysTrayWhatsThis);
         topGeneral->addWidget(mShowInSystemTrayGroup);
         QGridLayout* grid = new QGridLayout(mShowInSystemTrayGroup);
-        grid->setContentsMargins(dcm, dcm, dcm, dcm);
-        grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         grid->setColumnStretch(1, 1);
-        grid->setColumnMinimumWidth(0, indentWidth());
+        grid->setColumnMinimumWidth(0, gridIndentWidth());
 
         mAutoHideSystemTray = new ButtonGroup(mShowInSystemTrayGroup);
         connect(mAutoHideSystemTray, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotAutoHideSysTrayChanged);
@@ -1684,11 +1672,9 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "System Tray Tooltip"));
     topGeneral->addWidget(group);
     QGridLayout* grid = new QGridLayout(group);
-    grid->setContentsMargins(dcm, dcm, dcm, dcm);
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     grid->setColumnStretch(2, 1);
-    grid->setColumnMinimumWidth(0, indentWidth());
-    grid->setColumnMinimumWidth(1, indentWidth());
+    grid->setColumnMinimumWidth(0, gridIndentWidth());
+    grid->setColumnMinimumWidth(1, gridIndentWidth());
 
     mTooltipShowAlarms = new QCheckBox(i18nc("@option:check", "Show next &24 hours' alarms"), group);
     mTooltipShowAlarms->setMinimumSize(mTooltipShowAlarms->sizeHint());
@@ -1700,7 +1686,6 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget;
     QHBoxLayout* box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTooltipMaxAlarms = new QCheckBox(i18nc("@option:check", "Maximum number of alarms to show:"));
     mTooltipMaxAlarms->setMinimumSize(mTooltipMaxAlarms->sizeHint());
     box->addWidget(mTooltipMaxAlarms);
@@ -1729,7 +1714,6 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget; // this is to control the QWhatsThis text display area
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTooltipTimeToPrefixLabel = new QLabel(i18nc("@label:textbox", "Prefix:"));
     box->addWidget(mTooltipTimeToPrefixLabel);
     mTooltipTimeToPrefix = new QLineEdit();
@@ -1742,7 +1726,6 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "Alarm List"));
     topGeneral->addWidget(group);
     QHBoxLayout* hlayout = new QHBoxLayout(group);
-    hlayout->setContentsMargins(dcm, dcm, dcm, dcm);
     QVBoxLayout* colourLayout = new QVBoxLayout();
     colourLayout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(colourLayout);
@@ -1750,7 +1733,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget;  // to group widgets for QWhatsThis text
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing) / 2);
+    box->setSpacing(style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing) / 2);
     colourLayout->addWidget(widget);
     QLabel* label1 = new QLabel(i18nc("@label:listbox", "Disabled alarm color:"));
     box->addWidget(label1);
@@ -1763,7 +1746,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget;    // to group widgets for QWhatsThis text
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing) / 2);
+    box->setSpacing(style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing) / 2);
     colourLayout->addWidget(widget);
     QLabel* label2 = new QLabel(i18nc("@label:listbox", "Archived alarm color:"));
     box->addWidget(label2);
@@ -1781,10 +1764,8 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     group = new QGroupBox(i18nc("@title:group", "Alarm Message Windows"));
     topWindows->addWidget(group);
     grid = new QGridLayout(group);
-    grid->setContentsMargins(dcm, dcm, dcm, dcm);
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     grid->setColumnStretch(1, 1);
-    grid->setColumnMinimumWidth(0, indentWidth());
+    grid->setColumnMinimumWidth(0, gridIndentWidth());
     mWindowPosition = new ButtonGroup(group);
     connect(mWindowPosition, &ButtonGroup::buttonSet, this, &ViewPrefTab::slotWindowPosChanged);
 
@@ -1804,7 +1785,6 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     widget = new QWidget;   // this is to control the QWhatsThis text display area
     box = new QHBoxLayout(widget);
     box->setContentsMargins(0, 0, 0, 0);
-    box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mWindowButtonDelayLabel = new QLabel(i18nc("@label:spinbox", "Button activation delay (seconds):"));
     box->addWidget(mWindowButtonDelayLabel);
     mWindowButtonDelay = new QSpinBox();
@@ -1816,7 +1796,7 @@ ViewPrefTab::ViewPrefTab(StackedScrollGroup* scrollGroup)
     box->setStretchFactor(new QWidget(widget), 1);    // left adjust the controls
     grid->addWidget(widget, 2, 1, Qt::AlignLeft);
 
-    grid->setRowMinimumHeight(3, style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    grid->setRowMinimumHeight(3, style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     mModalMessages = new QCheckBox(i18nc("@option:check", "Message windows have a title bar and take keyboard focus"), group);
     mModalMessages->setMinimumSize(mModalMessages->sizeHint());
