@@ -1,7 +1,7 @@
 /*
  *  undo.cpp  -  undo/redo facility
  *  Program:  kalarm
- *  Copyright © 2005-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2005-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 
 #include "undo.h"
 
-#include "alarmcalendar.h"
 #include "functions.h"
+#include "resourcescalendar.h"
 #include "resources/resources.h"
 #include "lib/messagebox.h"
 #include "kalarm_debug.h"
@@ -835,13 +835,13 @@ UndoItem* UndoAdd::doRestore(bool setArchive)
 {
     // Retrieve the current state of the alarm
     qCDebug(KALARM_LOG) << "UndoAdd::doRestore:" << mEventId;
-    const KAEvent* ev = AlarmCalendar::getEvent(EventId(mResource.id(), mEventId));
-    if (!ev)
+    KAEvent event = mResource.event(mEventId);
+    if (!event.isValid())
     {
-        mRestoreError = ERR_NOT_FOUND;    // alarm is no longer in calendar
+        // Alarm is no longer in calendar, or its type is now disabled
+        mRestoreError = ERR_NOT_FOUND;
         return nullptr;
     }
-    KAEvent event(*ev);
 
     // Create a redo item to recreate the alarm.
     // Do it now, since 'event' gets modified by KAlarm::deleteEvent()
@@ -854,7 +854,7 @@ UndoItem* UndoAdd::doRestore(bool setArchive)
             if (setArchive)
                 event.setArchive();
             // Archive it if it has already triggered
-            KAlarm::UpdateResult status = KAlarm::deleteEvent(event, true);
+            KAlarm::UpdateResult status = KAlarm::deleteEvent(event, mResource, true);
             switch (status.status)
             {
                 case KAlarm::UPDATE_ERROR:
@@ -881,8 +881,11 @@ UndoItem* UndoAdd::doRestore(bool setArchive)
                 mRestoreError = ERR_TEMPLATE;
             break;
         case CalEvent::ARCHIVED:    // redoing the deletion of an archived alarm
-            KAlarm::deleteEvent(event);
+        {
+            Resource resource;
+            KAlarm::deleteEvent(event, resource);
             break;
+        }
         default:
             delete undo;
             mRestoreError = ERR_PROG;
@@ -992,13 +995,12 @@ UndoItem* UndoEdit::restore()
 {
     qCDebug(KALARM_LOG) << "UndoEdit::restore:" << mNewEventId;
     // Retrieve the current state of the alarm
-    const KAEvent* event = AlarmCalendar::getEvent(EventId(mResource.id(), mNewEventId));
-    if (!event)
+    KAEvent newEvent = mResource.event(mNewEventId);
+    if (!newEvent.isValid())
     {
         mRestoreError = ERR_NOT_FOUND;    // alarm is no longer in calendar
         return nullptr;
     }
-    KAEvent newEvent(*event);
 
     // Create a redo item to restore the edit
     const Undo::Type t = (type() == Undo::UNDO) ? Undo::REDO : (type() == Undo::REDO) ? Undo::UNDO : Undo::NONE;
@@ -1130,7 +1132,7 @@ UndoItem* UndoDelete::restore()
                 // It was archived when it was deleted
                 mEvent->setCategory(CalEvent::ARCHIVED);
                 mEvent->setResourceId(Resources::resourceForEvent(mEvent->id()).id());
-                const KAlarm::UpdateResult status = KAlarm::reactivateEvent(*mEvent, &mResource);
+                const KAlarm::UpdateResult status = KAlarm::reactivateEvent(*mEvent, mResource);
                 switch (status.status)
                 {
                     case KAlarm::UPDATE_KORG_FUNCERR:
@@ -1153,7 +1155,7 @@ UndoItem* UndoDelete::restore()
             }
             else
             {
-                const KAlarm::UpdateResult status = KAlarm::addEvent(*mEvent, &mResource, nullptr, true);
+                const KAlarm::UpdateResult status = KAlarm::addEvent(*mEvent, mResource, nullptr, true);
                 switch (status.status)
                 {
                     case KAlarm::UPDATE_KORG_FUNCERR:
@@ -1177,14 +1179,14 @@ UndoItem* UndoDelete::restore()
             KAlarm::setDontShowErrors(EventId(*mEvent), mDontShowErrors);
             break;
         case CalEvent::TEMPLATE:
-            if (KAlarm::addTemplate(*mEvent, &mResource) != KAlarm::UPDATE_OK)
+            if (KAlarm::addTemplate(*mEvent, mResource) != KAlarm::UPDATE_OK)
             {
                 mRestoreError = ERR_CREATE;
                 return nullptr;
             }
             break;
         case CalEvent::ARCHIVED:
-            if (!KAlarm::addArchivedEvent(*mEvent, &mResource))
+            if (!KAlarm::addArchivedEvent(*mEvent, mResource))
             {
                 mRestoreError = ERR_CREATE;
                 return nullptr;
