@@ -1,7 +1,7 @@
 /*
  *  undo.h  -  undo/redo facility
  *  Program:  kalarm
- *  Copyright © 2005-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2005-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,10 +50,10 @@ class Undo : public QObject
             mutable Resource resource;
             QStringList      dontShowErrors;
         };
-        class EventList : public QList<Event>
+        class EventList : public QVector<Event>
         {
         public:
-            void append(const KAEvent& e, const Resource& res)  { QList<Event>::append(Event(e, res)); }
+            void append(const KAEvent& e, const Resource& res)  { QVector<Event>::append(Event(e, res)); }
         };
 
         static Undo*       instance();
